@@ -1,5 +1,5 @@
 package Box::Calc::Role::Container;
-$Box::Calc::Role::Container::VERSION = '1.0100';
+$Box::Calc::Role::Container::VERSION = '1.0200';
 use strict;
 use warnings;
 use Moose::Role;
@@ -12,7 +12,7 @@ Box::Calc::Role::Container - Extends the L<Box::Calc::Role::Dimensional> role to
 
 =head1 VERSION
 
-version 1.0100
+version 1.0200
 
 =head1 METHODS
 
@@ -90,6 +90,18 @@ has outer_extent => (
     required    => 1,
 );
 
+=item max_weight
+
+The max weight of the items including the container. Defaults to 1000.
+
+=cut
+
+has max_weight => (
+    is          => 'ro',
+    isa         => 'Num',
+    default     => 1000,
+);
+
 around BUILDARGS => sub {
     my $orig      = shift;
     my $className = shift;
